@@ -40,7 +40,7 @@
 %% or refer to other properties, if desired. You can also use a {atom, semi-iolist(), semi-iolist()} formatter, which
 %% acts like a ternary operator's true/false branches.
 %%
-%% The metadata properties date,time, message, and severity will always exist.  
+%% The metadata properties date,time, message, severity, and sev will always exist.  
 %% The properties pid, file, line, module, and function will always exist if the parser transform is used.
 %%
 %% Example:
@@ -86,6 +86,14 @@ output(time,Msg) ->
     T;
 output(severity,Msg) ->
     atom_to_list(lager_msg:severity(Msg));
+output(sev,Msg) ->
+    %% Write brief acronym for the severity level (e.g. debug -> $D)
+    [lager_util:level_to_chr(lager_msg:severity(Msg))];
+output(metadata, Msg) ->
+    output({metadata, "=", " "}, Msg);
+output({metadata, IntSep, FieldSep}, Msg) ->
+    MD = lists:keysort(1, lager_msg:metadata(Msg)),
+    string:join([io_lib:format("~s~s~p", [K, IntSep, V]) || {K, V} <- MD], FieldSep);
 output(Prop,Msg) when is_atom(Prop) ->
     Metadata = lager_msg:metadata(Msg),
     make_printable(get_metadata(Prop,Metadata,<<"Undefined">>));
@@ -233,6 +241,26 @@ basic_test_() ->
                             []),
                         [{server,{pid, ["(", pid, ")"], ["(Unknown Server)"]}}]
                     )))
+        },
+        {"Metadata can be printed in its enterity",
+            ?_assertEqual(iolist_to_binary(["bar=2 baz=3 foo=1"]),
+                iolist_to_binary(format(lager_msg:new("Message",
+                            Now,
+                            error,
+                            [{foo, 1}, {bar, 2}, {baz, 3}],
+                            []),
+                        [metadata]
+                    )))
+        },
+        {"Metadata can be printed in its enterity with custom seperators",
+            ?_assertEqual(iolist_to_binary(["bar->2, baz->3, foo->1"]),
+                iolist_to_binary(format(lager_msg:new("Message",
+                            Now,
+                            error,
+                            [{foo, 1}, {bar, 2}, {baz, 3}],
+                            []),
+                        [{metadata, "->", ", "}]
+                    )))
         }
     ].
 
